#
# spec file for package avogadro
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           avogadro
Version:        1.1.1
Release:        3.41
Summary:        A Molecular design tool
License:        GPL-2.0
Group:          Productivity/Editors/Other
Url:            http://avogadro.sourceforge.net/wiki/Main_Page
Source0:        http://sourceforge.net/projects/avogadro/files/avogadro/%{version}/avogadro-%{version}.tar.bz2
Source1:        %{name}.png
Source2:        baselibs.conf
# PATCH-FIX-UPSTREAM avogadro-1.1.0-avopkg-fix-echo.patch ledest@gmail.com
Patch1:         avogadro-1.1.0-avopkg-fix-echo.patch
# PATCH-FIX-UPSTREAM avogadro-cmake-3.2.patch -- sfalken@gmail.com
Patch2:         avogadro-cmake-3.2.patch
Patch3:         arm-qreal-vs-double.patch
BuildRequires:  boost-devel
BuildRequires:  cmake
BuildRequires:  docbook-utils
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  glew-devel
BuildRequires:  glu-devel
BuildRequires:  libeigen2-devel
BuildRequires:  libopenbabel-devel >= 2.3.1
BuildRequires:  libqt4-devel >= 4.5.1
BuildRequires:  python-devel
BuildRequires:  python-numpy-devel
BuildRequires:  python-qt4-devel
BuildRequires:  python-sip-devel
BuildRequires:  xorg-x11-devel
BuildRequires:  xorg-x11-libX11-devel
BuildRequires:  xorg-x11-libXext-devel
BuildRequires:  pkgconfig(glu)
Requires:       libavogadro1 = %{version}
Requires:       openbabel
Requires:       python-numpy
Requires:       python-sip

%description
Avogadro is an advanced molecular editor designed
for cross-platform use in computational chemistry,
molecular modeling, bioinformatics, materials science,
and related areas. It offers flexible rendering and
a powerful plugin architecture.

%package -n libavogadro1
Summary:        A Molecular design tool
Group:          Development/Libraries/C and C++
Provides:       libavogadro = %{version}-%{release}

%description -n libavogadro1
This package contains the shared libraries for Avogadro.

Avogadro is an advanced molecular editor designed
for cross-platform use in computational chemistry,
molecular modeling, bioinformatics, materials science,
and related areas. It offers flexible rendering and
a powerful plugin architecture.

%package devel
Summary:        Development files for Avogadro
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}

%description devel
This package contains files to develop applications using
Avogadros libraries.

%package -n python-avogadro
Summary:        A python wrapper to avogadro
Group:          Development/Languages/Python
Requires:       python-numpy
Requires:       python-sip

%description -n python-avogadro
This package contains the python wrapper to Avogadro.

Avogadro is an advanced molecular editor designed
for cross-platform use in computational chemistry,
molecular modeling, bioinformatics, materials science,
and related areas. It offers flexible rendering and
a powerful plugin architecture.

%prep
%setup -q
%patch1 -p1
%patch2 -p1
%patch3

%build
%cmake \
	-DENABLE_GLSL=ON \
	-DENABLE_UPDATE_CHECKER=OFF \
	-DENABLE_ZMATRIX_TOOL=ON \
	-DENABLE_PYTHON=ON \
	-DCMAKE_BUILD_TYPE=RelWithDebInfo 
make %{?_smp_mflags}

%install
cd build
%makeinstall

mkdir -p %{buildroot}/%{_datadir}/qt4/mkspecs/
mv %{buildroot}%{_prefix}/features %{buildroot}/%{_datadir}/qt4/mkspecs/
# Create the system menu entry
mkdir -p %{buildroot}%{_datadir}/applications
cat > %{buildroot}%{_datadir}/applications/%{name}.desktop << EOF
[Desktop Entry]
Name=Avogadro
Comment=%{summary}
GenericName=Avogadro
Exec=%{name}
Icon=%{name}
Terminal=0
Categories=KDE;Education;Chemistry;
Type=Application
X-SuSE-translate=false
EOF

# icon
install -D -m644 %{SOURCE1} %{buildroot}%{_datadir}/pixmaps/%{name}.png
%if "%{_lib}" == "lib64"
	mkdir -p %{buildroot}%{python_sitearch}
	if [ ! -e %{buildroot}%{python_sitearch}/Avogadro.so ]; then
	    find %{buildroot} -name 'Avogadro.so' | xargs mv -t %{buildroot}%{python_sitearch}/
        fi
	find %{buildroot}%{_lib} -name "python*" |xargs rm -rf
%endif
%fdupes %{buildroot}%{_datadir}/libavogadro/shaders/
%fdupes %{buildroot}%{_datadir}/%{name}/

%post -n libavogadro1 -p /sbin/ldconfig

%postun -n libavogadro1 -p /sbin/ldconfig

%files
%defattr(-,root,root,-)
%doc AUTHORS ChangeLog COPYING
%{_mandir}/man1/avogadro.1.gz
%{_mandir}/man1/avopkg.1.gz
%{_bindir}/avogadro
%{_bindir}/avopkg
%dir %{_datadir}/libavogadro
%{_datadir}/libavogadro/shaders/
%{_datadir}/%{name}/
%{_datadir}/pixmaps/*.png
%{_datadir}/applications/%{name}.desktop
#plugins not libraries
%dir %{_libdir}/avogadro
%dir %{_libdir}/avogadro/1_1
%dir %{_libdir}/avogadro/1_1/colors
%dir %{_libdir}/avogadro/1_1/engines
%dir %{_libdir}/avogadro/1_1/extensions
%dir %{_libdir}/avogadro/1_1/tools
%{_libdir}/avogadro/1_1/*/*.so
%dir %{_datadir}/libavogadro/engineScripts
%dir %{_datadir}/libavogadro/extensionScripts
%{_datadir}/libavogadro/engineScripts/wireframe.py
%{_datadir}/libavogadro/extensionScripts/example.py

%files devel
%defattr(-,root,root,-)
%dir %{_includedir}/avogadro
%{_includedir}/avogadro/*.h
%dir %{_libdir}/avogadro/1_1/cmake
%{_libdir}/libavogadro.so
%{_libdir}/libavogadro_OpenQube.so

%{_libdir}/avogadro/1_1/cmake/*
%{_libdir}/avogadro/1_1/*.cmake
%{_libdir}/avogadro/*.cmake
%{_libdir}/pkgconfig/*.pc
%{_datadir}/qt4/mkspecs/features/avogadro.prf

%files -n libavogadro1
%defattr(-,root,root,-)
%{_libdir}/*.so.*

%files -n python-avogadro
%defattr(-,root,root,-)
# installed with python support
%{python_sitearch}/Avogadro.so

%changelog
* Sat Apr  4 2015 dmueller@suse.com
- add arm-qreal-vs-double.patch
* Tue Mar 24 2015 sfalken@opensuse.org
- Added patch to fix building against cmake >= 3.2, libX11 is no
  longer magically implied. (sf#avogadro/bugs/746)
  + avogadro-cmake-3.2.patch
* Sat Feb 14 2015 Led <ledest@gmail.com>
- fix using 'echo' command in avopkg script
- add patches:
  * avogadro-1.1.0-avopkg-fix-echo.patch
* Thu Dec 18 2014 p.drouand@gmail.com
- Update to version 1.1.1
  * Rudimentary support for retinal display Macs
  * Support for manual adjustment of the view
  * DNA/RNA builder
  * Simple LAMMPS input generator for water
  * PSI4 input generator added
  * Fixed QTAIM to work on Windows
  * Updated gl2ps snapshot
- Remove fixed patches
  * avogadro-1.1.0-no-return-in-nonvoid-function.patch
  * MopacAuxReaderFix.patch
  * shlib-pic-flag.patch
- Use %%cmake macro
* Thu Dec 18 2014 p.drouand@gmail.com
- Update to version 1.1.1
  * Rudimentary support for retinal display Macs
  * Support for manual adjustment of the view
  * DNA/RNA builder
  * Simple LAMMPS input generator for water
  * PSI4 input generator added
  * Fixed QTAIM to work on Windows
  * Updated gl2ps snapshot
- Remove fixed patches
  * avogadro-1.1.0-no-return-in-nonvoid-function.patch
  * MopacAuxReaderFix.patch
  * shlib-pic-flag.patch
- Use %%cmake macro
* Sun Aug 11 2013 schwab@suse.de
- Compile with %%{optflags}
- Use RelWithDebInfo build type not to strip binaries
- shlib-pic-flag.patch: Always use PIC in shlib objects
* Tue Feb  5 2013 stecue@gmail.com
- added MopacAuxReaderFix.patch to avoid crash when loading aux.
- fixed build on SLES
- split off python package
  (also use sitearch for arch-dependent files)
* Sun Feb  3 2013 lars@linux-schulserver.de
- added avogadro-1.1.0-no-return-in-nonvoid-function.patch
* Sun Oct  7 2012 lars@linux-schulserver.de
- update to 1.1.0:
  + Fix crash with dipole moment after optimization (PR#3521044)
  + Add test files for QTAIM analysis, including diborane(B2H6),
    C4H4, and HCO2. These files will be used for a tutorial
  + Fix residue and atom code assignment
  + be conservative about changing elements when copying atoms
    for the same reason
- removed avogadro-boost148.patch and avogadro-nostrip.patch
* Fri Oct  5 2012 coolo@suse.com
- glew no longer requires glu, so buildrequire it explicitly
* Mon Sep 24 2012 schwab@linux-m68k.org
- Use %%{optflags} and don't strip binaries
* Tue Apr  3 2012 idonmez@suse.com
- Fix compile with boost 1.48
* Wed Feb 15 2012 lars@linux-schulserver.de
- fix Copyright header in specfile and license (spdx format)
* Tue Nov 29 2011 ro@suse.de
- use _lib macro to determine lib suffix
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
- Implement baselibs for package
* Mon Aug  8 2011 toddrme2178@gmail.ccom
- Added check for duplicate files (fix for RPMLINT warning)
- Removed name from summary (fix for RPMLINT warning)
- Cleaned up spec file formatting
* Mon Jun  6 2011 andrea@opensuse.org
- Spec file clean up
* Fri May 20 2011 stecue@gmail.com
- removed the obsolete patches due to the new upstream version.
- no more crash on openSUSE 11.4 when starting.
- new upstream version (bugfix release)
  * Fixed building of translations on Linux and Mac OS X.
  * Fixed issues with newer versions of SIP
  * Import Avogadro automatically in the Python terminal
  * Some fixes/adjustments for newer versions of Open Babel
  * Fixed a bug in the bounds for cubes, now isosurfaces align to molecules in all cases
  * Added picking support in wireframe - enables editing of atoms in this mode
  * Fixed some crashes when drawing with adjust hydrogens on
  * Ensure the GAMESS input generator updates when atoms are added, removed or updated
  * Added some missing entries in the GAMESS input dialog
  * Fixes to the NWChem input generator
  * Add LARGE keyword to MOPAC input files to give full output of MOs
  * Fixed autobonding in animations when rendering in POV-Ray for video
  * Removed some old CMake code that was no longer needed
  * Made Linguist optional for Avogadro builds
  * Fixes for compilation on Windows
  * Fixed a few memory leaks
* Tue Oct 19 2010 andrea@opensuse.org
- removed proprietary test files from the tarball bnc#645306
* Tue Oct 19 2010 andrea@opensuse.org
- removed proprietary test files from the tarball bnc#645306
* Fri Oct  8 2010 coolo@novell.com
- move the changelog to .changes to prepare factory submission
* Fri Nov  6 2009 andrea@opensuse.org
- new upstream version (Stable release)
* Sat Jul 25 2009 andrea@opensuse.org
- new upstream version (bugfix release)
* Fri Jun  5 2009 andrea@opensuse.org
- new upstream version (bugfix release)
* Wed Jun  3 2009 andrea@opensuse.org
- new upstream version 0.9.5
- disabled update checker
* Tue May  5 2009 andrea@opensuse.org
- new upstream version 0.9.4
* Wed Apr  8 2009 andrea@opensuse.org
- fixed bug 2737083 :
  https://sourceforge.net/tracker/?func=detail&aid=2737083&group_id=165310&atid=835077
* Sat Apr  4 2009 andrea@opensuse.org
- new upstream version 0.9.3
* Thu Mar 19 2009 andrea@opensuse.org
- update to version 0.9.2
- added several BuildRequires to allow GLSL  module and
  docs compilation, python module still broken
- added fdupes to symlink duplicate files
* Mon Feb 23 2009 andrea@opensuse.org
- update to version 0.9.1
* Wed Jun 11 2008 andrea@opensuse.org
- update to version 0.8.1
- lots of fixing and improving:
    for more info check here: http://avogadro.openmolecules.net/wiki/Avogadro_0.8.1
- made rpmlint happier
* Fri May 30 2008 andrea@opensuse.org
- update to version 0.8.0
* Mon Mar 24 2008 andrea@opensuse.org
- update to version 0.6.1
* Fri Dec 21 2007 andrea@opensuse.org
- Fixed URL project page
- Fixed libavogadro0 and avogadro-devel package
- added libavogadro like obsoletes
- follow shared library packagin policy:
  rename libavogadro to libavogadro0
- create a devel package containing the headers files
- make the compiler happier: added avogadro-0.2.0-mathmeaning.patch
* Sun Dec 16 2007 andrea@opensuse.org
- First spec making
